/**********************************************************************
 *
 * niupepabrowsetools.cpp -- 
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: niupepabrowsetools.cpp 1023 2000-03-08 20:44:48Z sjboddie $
 *
 *********************************************************************/

#include "niupepabrowsetools.h"
#include "OIDtools.h"
#include "cgiutils.h"
#include "browsetools.h"

static void output_niupepa_controls (cgiargsclass &args, const text_tarray &ibuttons, 
				     recptproto *collectproto, displayclass &disp,
				     outconvertclass &outconvert, ostream &textout, 
				     ostream &logout) {

  bool hastxt = false, hasimg = false, hasprevimg = false;
  text_tarray buttons;
  text_t &arg_gg = args["gg"];
  text_t &arg_d = args["d"];
  FilterResponse_t response;
  text_tset metadata;
  text_t doctype;
  metadata.insert ("hastxt");
  metadata.insert ("hasimg");
  metadata.insert ("hasprevimg");
  metadata.insert ("doctype");
  if (!get_info (arg_d, args["c"], metadata, false, collectproto, response, logout))
    return;

  if (response.docInfo[0].metadata["hastxt"].values[0] == "1") hastxt = true;
  if (response.docInfo[0].metadata["hasimg"].values[0] == "1") hasimg = true;
  if (response.docInfo[0].metadata["hasprevimg"].values[0] == "1") hasprevimg = true;

  MetadataInfo_tmap::iterator it = response.docInfo[0].metadata.find ("doctype");
  if (it != response.docInfo[0].metadata.end()) {
    if (! (*it).second.values.empty()) doctype = (*it).second.values[0];
  }

  if (doctype == "Description") {
    // abstract
    text_t paper = substr (arg_d.begin(), (arg_d.end() - 8));
    buttons.push_back ("_document:imageviewpaper_(" + paper + ")");
    buttons.push_back ("_document:imageabstractintro_");

  } else if (doctype == "Commentary") {
    // commentary


  } else {
    // newspaper page

    if (arg_gg == "full") {
      if (hastxt) buttons.push_back ("_document:imageviewtext_");
      if (hasprevimg) buttons.push_back ("_document:imageprevimage_");
    } else if (arg_gg == "prev") {
      if (hastxt) buttons.push_back ("_document:imageviewtext_");
      if (hasimg) buttons.push_back ("_document:imagefullimage_");
    } else {
      if (hasimg) buttons.push_back ("_document:imagefullimage_");
      if (hasprevimg) buttons.push_back ("_document:imageprevimage_");
    }

    // see if paper has an abstract
    text_t abstract;
    get_top (arg_d, abstract);
    abstract += "abstract";
    metadata.erase (metadata.begin(), metadata.end());
    if (get_info (abstract, args["c"], metadata, false, collectproto, response, logout))
      buttons.push_back ("_document:imageviewabstract_(" + abstract + "&gg=text)");
  } 

  if (args["u"] != "1") {

    text_tarray::const_iterator here = ibuttons.begin();
    text_tarray::const_iterator end = ibuttons.end();
    
    while (here != end) {
      
      if (*here == "Detach")
	buttons.push_back ("_document:imagedetach_");
      else if (*here == "Highlight" && arg_gg == "text") {
	if (args["hl"] == "1") 
	  buttons.push_back ("_document:imagenohighlight_");
	else 
	  buttons.push_back ("_document:imagehighlight_");
	
      } else if ((*here == "Expand Text") && (doctype.empty()) && (arg_gg == "text")) {
	if (args.getintarg("gt"))
	  buttons.push_back ("_document:imagecontracttext_");
	else 
	  buttons.push_back ("_document:imageexpandtext_");
      }
      here ++;
    }
    
    here = buttons.begin();
    end = buttons.end();
    int count = 0;
    while (here != end) {
      if ((count != 0) && ((count % 3) == 0)) textout << "<br>\n";
      textout << outconvert << disp << *here;
      count ++;
      here ++;
    }
  }
}



void output_niupepa_toc (cgiargsclass &args, browsermapclass *browsermap,
			 formatinfo_t &formatinfo, recptproto *collectproto,
			 displayclass &disp, outconvertclass &outconvert,
			 ostream &textout, ostream &logout) {

  int tabcount = 0;
  text_t &arg_d = args["d"];
  
  // get the cover image (if there is one) and the control buttons
  // if we're inside a book
  if (!arg_d.empty()) {
    textout << outconvert << disp 
	    << "<center>\n"
	    << "<p><table cellpadding=0 cellspacing=0 width=_pagewidth_><tr>\n"
	    << "<td align=left valign=top>\n";
    output_titles (args, collectproto, formatinfo, disp, outconvert, textout, logout);
    textout << "<p>\n";
  }

  if (formatinfo.DocumentContents || arg_d.empty()) {
    if (args.getintarg("gc") == 1) {
      
      // expanded table of contents
      expanded_contents (args, tabcount, false, browsermap, formatinfo, 
			 collectproto, disp, outconvert, textout, logout);
    } else {
      
      // contracted table of contents
      contracted_contents (args, tabcount, false, browsermap, formatinfo, 
			   collectproto, disp, outconvert, textout, logout);
    }
  }

  if (!arg_d.empty()) {
    output_niupepa_controls (args, formatinfo.DocumentButtons, collectproto, 
			     disp, outconvert, textout, logout);

    textout << outconvert << disp
	    << "</td>\n"
	    << "<td align=right valign=top>"
	    << "_document:imagethispaper_\n"
	    << "</td></tr>\n"
	    << "</table>\n"
	    << "</center>\n";
  }
  textout << outconvert << disp << "_iconblankbar_\n";
}








